# ITR

This Python module implements the ITR methodology, elaborated in this [Functional Overview](https://github.com/os-climate/ITR/blob/main/docs/FunctionalOverview.rst).

[A graphical representation](https://github.com/os-climate/ITR/blob/main/docs/Calculation.md) of the fundamental calculations is also available in the [docs](https://github.com/os-climate/ITR/tree/main/docs) directory.

A companion GitHub repository hosts user interface code and additional examples:

[https://github.com/os-climate/ITR-examples](https://github.com/os-climate/ITR-examples)

## Getting started with the user interface

This documentation is currently in the process of being updated due to a reorganisation of the repository.
